OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendar",
    "Today" : "Hari ini",
    "Day" : "Hari",
    "Week" : "Minggu",
    "Month" : "Bulan",
    "Download" : "Muat turun",
    "Delete" : "Padam",
    "Share link" : "Share link",
    "can edit" : "boleh mengubah",
    "New calendar" : "Kalendar baru",
    "Cancel" : "Batal",
    "Email" : "Email",
    "from" : "dari",
    "to" : "kepada",
    "never" : "jangan",
    "Repeat" : "Ulang",
    "Monday" : "Isnin",
    "More" : "Lanjutan",
    "Save" : "Simpan",
    "Update" : "Kemaskini",
    "Personal" : "Peribadi",
    "Attendees" : "Jemputan",
    "Activity" : "Aktiviti",
    "Close" : "Tutup",
    "Daily" : "Setiap hari",
    "Weekly" : "Setiap minggu",
    "Location" : "Lokasi",
    "Description" : "Keterangan",
    "Mail" : "Mel",
    "Play" : "Main"
},
"nplurals=1; plural=0;");
